@@ -23,7 +23,6 @@
 #include <KLocalizedContext>
 #include <KLocalizedString>
 
-#include "about.h"
 #include "alligator-version.h"
 #include "alligatorsettings.h"
 #include "database.h"
@@ -34,6 +33,10 @@
 #include "feedsproxymodel.h"
 #include "fetcher.h"
 
+#ifdef Q_OS_WINDOWS
+#include <windows.h>
+#endif
+
 #ifdef Q_OS_ANDROID
 Q_DECL_EXPORT
 #endif
@@ -61,6 +64,7 @@ int main(int argc, char *argv[])
     font.setPointSize(10);
     app.setFont(font);
 #endif
+    KLocalizedString::setApplicationDomain("alligator");
 
     QCoreApplication::setOrganizationName(QStringLiteral("KDE"));
     QCoreApplication::setOrganizationDomain(QStringLiteral("kde.org"));
@@ -71,8 +75,8 @@ int main(int argc, char *argv[])
                      QStringLiteral(ALLIGATOR_VERSION_STRING),
                      i18n("Feed Reader"),
                      KAboutLicense::GPL,
-                     i18n("© 2020 KDE Community"));
-    about.addAuthor(i18n("Tobias Fella"), QString(), QStringLiteral("fella@posteo.de"));
+                     i18n("© 2020-2022 KDE Community"));
+    about.addAuthor(i18n("Tobias Fella"), QString(), QStringLiteral("fella@posteo.de"), QStringLiteral("https://tobiasfella.de"));
     KAboutData::setApplicationData(about);
 
     qmlRegisterType<FeedsModel>("org.kde.alligator", 1, 0, "FeedsModel");
@@ -82,13 +86,17 @@ int main(int argc, char *argv[])
     qmlRegisterType<EntriesModel>("org.kde.alligator", 1, 0, "EntriesModel");
     qmlRegisterType<EntriesProxyModel>("org.kde.alligator", 1, 0, "EntriesProxyModel");
 
-    qmlRegisterSingletonInstance("org.kde.alligator", 1, 0, "AboutType", &AboutType::instance());
+    qmlRegisterSingletonType("org.kde.alligator", 1, 0, "About", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
+        return engine->toScriptValue(KAboutData::applicationData());
+    });
+
+    AlligatorSettings settings;
+    qmlRegisterSingletonInstance("org.kde.alligator", 1, 0, "Config", &settings);
     qmlRegisterSingletonInstance("org.kde.alligator", 1, 0, "Fetcher", &Fetcher::instance());
     qmlRegisterSingletonInstance("org.kde.alligator", 1, 0, "Database", &Database::instance());
 
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-    KLocalizedString::setApplicationDomain("alligator");
 
     QCommandLineParser parser;
     parser.setApplicationDescription(i18n("RSS/Atom Feed Reader"));
@@ -105,10 +113,6 @@ int main(int argc, char *argv[])
         Database::instance().addFeed(feedURL);
     about.processCommandLine(&parser);
 
-    AlligatorSettings settings;
-
-    engine.rootContext()->setContextProperty(QStringLiteral("_settings"), &settings);
-
     QObject::connect(&app, &QCoreApplication::aboutToQuit, &settings, &AlligatorSettings::save);
 
     Database::instance();
